#!/usr/bin/env bash

set -o errexit
set -o nounset

declare -r CONTEXT_LOG=context.log
declare -r PDF_EXTENSION='.pdf'
declare -r TEX_EXTENSION='.tex'

declare contextFile
declare compileAll
declare compileContextFile
declare pdfFile

if [[ ${#} -ge  1 && ${1} == "--all" ]] ; then
  compileAll="y"
  shift
else
  compileAll="n"
fi
if [[ ${#} -ge 1 ]] ; then
  echo "Got to many parameters: (${*})"
  echo "    $(basename ${0}) [--all]"
  exit 1
fi
rm -f ${CONTEXT_LOG}

for contextFile in *${TEX_EXTENSION} ; do
  if [[ ${compileAll} == "y" ]] ; then
    compileContextFile="y"
  else
    compileContextFile="n"
    pdfFile=$(basename ${contextFile} ${TEX_EXTENSION})${PDF_EXTENSION}
    if [[ ! -f ${pdfFile} ]] ; then
      compileContextFile="y"
    elif [[ ${pdfFile} -ot ${contextFile} ]] ; then
      compileContextFile="y"
    fi
  fi
  if [[ ${compileContextFile} == "y" ]] ; then
    echo "Process: ${contextFile}"
    texexec --purgeall --timeout=15 ${contextFile} >${CONTEXT_LOG}
  else
    echo "${contextFile} was already up to date"
  fi
done
echo Processed all files